import { FormKitTypeDefinition, type FormKitFrameworkContext } from '@formkit/core';
import {
  casts,
  createSection,
  help,
  icon,
  inner,
  label,
  outer,
  prefix,
  suffix,
  textInput,
  wrapper,
} from '@formkit/inputs';
import { messages } from '../sections/messages';
import { h, markRaw } from 'vue';

/**
 * Input definition for a text.
 * @public
 */
export const text: FormKitTypeDefinition = {
  /**
   * The actual schema of the input, or a function that returns the schema.
   */
  schema: outer(
    wrapper(label('$label'), inner(icon('prefix', 'label'), prefix(), textInput(), suffix(), icon('suffix'))),
    help('$help'),
    messages(),
  ),
  /**
   * The type of node, can be a list, group, or input.
   */
  type: 'input',
  /**
   * The family of inputs this one belongs too. For example "text" and "email"
   * are both part of the "text" family. This is primary used for styling.
   */
  family: 'text',
  /**
   * An array of extra props to accept for this input.
   */
  props: [
    // 'label2',
  ],
  /**
   * Forces node.props.type to be this explicit value.
   */
  // forceTypeProp: 'text',
  /**
   * Additional features that should be added to your input
   */
  features: [casts],
  /**
   * The key used to memoize the schema.
   */
  // schemaMemoKey: 'g2f31c24kjh',
};

// @ts-ignore
const custom_FComponent = {
  schema: createSection('input', () => ({
    $cmp: 'FComponent',
    props: { context: '$node.context' },
  }))(),
  library: markRaw(((props: { context: FormKitFrameworkContext } /* context */) => {
    return h('XxxxCmp', {
      id: props.context.id,
      value: props.context._value,
      ...props.context.attrs,
      onInput: props.context.handlers.DOMInput,
      onBlur: props.context.handlers.blur,
    });
  }) satisfies import('vue').FunctionalComponent<{ context: FormKitFrameworkContext }>),
};
